/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

/* Copyright (C) 2007 con terra GmbH (http://www.conterra.de)
 * All rights reserved
 *
 * $Id: ChartLabels.java,v 1.1 2007/12/10 13:57:13 drewnak Exp $
 *
 * created by:      drewnak
 * created at :     10.12.2007
 * created at :     11:48:39
 *
 * modified by:     $Author: drewnak $
 * modified at:     $Date: 2007/12/10 13:57:13 $
 */
package de.intevation.gnv.chart;

/**
 * This class stores some strings used for decorating charts (e.g. title,
 * subtitle, etc).
 *
 * @author drewnak
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a> Changes and codecleanup
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ChartLabels {
    /**
     *
     */
    private String title;

    /**
     *
     */
    private String subtitle;

    /**
     *
     */
    private String domainAxisLabel;

    /**
     *
     */
    private String rangeAxisLabel;

    /**
     *
     */
    private String parameterName;


    /**
     * Constructor
     *
     * @param title Title
     * @param subtitle Subtitle
     * @param domainAxisLabel X-axis label
     */
    public ChartLabels(String title, String subtitle, String domainAxisLabel) {
        this(title, subtitle, domainAxisLabel, null);
    }

    /**
     * Constructor
     *
     * @param title Title
     * @param subtitle Subtitle
     * @param domainAxisLabel X-axis label
     * @param rangeAxisLabel Y-axis label
     */
    public ChartLabels(
        String title,
        String subtitle,
        String domainAxisLabel,
        String rangeAxisLabel
    ) {
        this(title, subtitle, domainAxisLabel, rangeAxisLabel, null);
    }


    /**
     * Constructor
     *
     * @param title Title
     * @param subtitle Subtitle
     * @param domainAxisLabel X-axis label
     * @param rangeAxisLabel Y-axis label
     * @param parameterName Name of a given parameter in the chart.
     */
    public ChartLabels(
        String title,
        String subtitle,
        String domainAxisLabel,
        String rangeAxisLabel,
        String parameterName
    ) {
        this.title           = title;
        this.subtitle        = subtitle;
        this.domainAxisLabel = domainAxisLabel;
        this.rangeAxisLabel  = rangeAxisLabel;
        this.parameterName   = parameterName;
    }

    /**
     * @return the title
     */
    public String getTitle() {
        return this.title;
    }


    /**
     * @return the subtitle
     */
    public String getSubtitle() {
        return subtitle;
    }

    /**
     * @return the timeAxisLabel
     */
    public String getDomainAxisLabel() {
        return this.domainAxisLabel;
    }


    /**
     * @return the y-axis label
     */
    public String getRangeAxisLabel() {
        return this.rangeAxisLabel;
    }


    /**
     * @return the parameter name
     */
    public String getParameterName() {
        return this.parameterName;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
